@@ -8,6 +8,7 @@ import tempfile
 
 IMPLEMENTATION = platform.python_implementation()
 IS_PYPY = IMPLEMENTATION == "PyPy"
+IS_GRAALPY = IMPLEMENTATION == "GraalVM"
 IS_CPYTHON = IMPLEMENTATION == "CPython"
 IS_WIN = sys.platform == "win32"
 IS_MAC_ARM64 = sys.platform == "darwin" and platform.machine() == "arm64"
@@ -33,18 +34,20 @@ def fs_supports_symlink():
     if _CAN_SYMLINK is None:
         can = False
         if hasattr(os, "symlink"):
-            if IS_WIN:
-                with tempfile.NamedTemporaryFile(prefix="TmP") as tmp_file:
-                    temp_dir = os.path.dirname(tmp_file.name)
-                    dest = os.path.join(temp_dir, f"{tmp_file.name}-{'b'}")
-                    try:
-                        os.symlink(tmp_file.name, dest)
-                        can = True
-                    except (OSError, NotImplementedError):
-                        pass
-                LOGGER.debug("symlink on filesystem does%s work", "" if can else " not")
-            else:
-                can = True
+            # Creating a symlink can fail for a variety of reasons, indicating that the filesystem does not support it.
+            # E.g. on Linux with a VFAT partition mounted.
+            with tempfile.NamedTemporaryFile(prefix="TmP") as tmp_file:
+                temp_dir = os.path.dirname(tmp_file.name)
+                dest = os.path.join(temp_dir, f"{tmp_file.name}-{'b'}")
+                try:
+                    os.symlink(tmp_file.name, dest)
+                    can = True
+                except (OSError, NotImplementedError):
+                    pass  # symlink is not supported
+                finally:
+                    if os.path.lexists(dest):
+                        os.remove(dest)
+            LOGGER.debug("symlink on filesystem does%s work", "" if can else " not")
         _CAN_SYMLINK = can
     return _CAN_SYMLINK
 
@@ -55,6 +58,7 @@ def fs_path_id(path: str) -> str:
 
 __all__ = (
     "IS_CPYTHON",
+    "IS_GRAALPY",
     "IS_MAC_ARM64",
     "IS_PYPY",
     "IS_WIN",
