@@ -17,7 +17,7 @@ TAR = next((target for target in ("gtar", "tar") if shutil.which(target)), None)
 
 
 def compatible_is_tar_present() -> bool:
-    return TAR and "--exclude-caches" in check_output(args=[TAR, "--help"], text=True)
+    return TAR and "--exclude-caches" in check_output(args=[TAR, "--help"], text=True, encoding="utf-8")
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Windows does not have tar")
@@ -27,6 +27,6 @@ def test_cachedir_tag_ignored_by_tag(tmp_path: Path) -> None:
     cli_run(["--activators", "", "--without-pip", str(venv)])
 
     args = [TAR, "--create", "--file", "/dev/null", "--exclude-caches", "--verbose", venv.name]
-    tar_result = run(args=args, capture_output=True, text=True, cwd=tmp_path)
+    tar_result = run(args=args, capture_output=True, text=True, encoding="utf-8", cwd=tmp_path)
     assert tar_result.stdout == ".venv/\n.venv/CACHEDIR.TAG\n"
     assert tar_result.stderr == f"{TAR}: .venv/: contains a cache directory tag CACHEDIR.TAG; contents not dumped\n"
